pub struct Callout {
pub text: String,
pub arrow_direction: ArrowDirection,
pub arrow_size: f32,
pub timing: TimingConfig,
pub style: CssStyle,
pub timeline: Vec<TimelineStep>,
pub stagger: Option<f32>,
}Expand description
Speech bubble with a directional arrow.
CSS-like properties go in style:
style.background— bubble background color (default:"#333333")style.color— text color (default:"#FFFFFF")style.border-radius— corner radius (default:8)style.font-size— text size (default:16)
Fields
text: Stringarrow_direction: ArrowDirectionarrow_size: f32timing: TimingConfigstyle: CssStyletimeline: Vec<TimelineStep>stagger: Option<f32>Trait Implementations
Sourceimpl Animatable for Callout
impl Animatable for Callout
fn animation_effects(&self) -> &[AnimationEffect]
Sourcefn timeline_steps(&self) -> &[TimelineStep]
fn timeline_steps(&self) -> &[TimelineStep]
Timed animation steps (
timeline field): each step’s animations are
resolved with delay += step.at. Empty by default.Sourceimpl<'de> Deserialize<'de> for Callout
impl<'de> Deserialize<'de> for Callout
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Callout
impl JsonSchema for Callout
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Painter for Callout
impl Painter for Callout
Sourcefn paint_content(
&self,
canvas: &Canvas,
layout: &BoxLayout,
_props: &AnimatedProperties,
ctx: &PaintCtx,
)
fn paint_content( &self, canvas: &Canvas, layout: &BoxLayout, _props: &AnimatedProperties, ctx: &PaintCtx, )
Paint the component’s content into the canvas. The canvas is
already translated to the content-box origin and clipped if
overflow: hidden was set. Generic decorations (bg, border,
shadow) are already painted by the engine. Read moreSourcefn intrinsic_size(
&self,
_available: AvailableSize,
_ctx: &MeasureCtx,
) -> Option<(f32, f32)>
fn intrinsic_size( &self, _available: AvailableSize, _ctx: &MeasureCtx, ) -> Option<(f32, f32)>
Optional intrinsic measurement for leaves like
text, image,
codeblock. Return None to let taffy compute the size from the
CSS style alone. available mirrors taffy’s AvailableSpace.Auto Trait Implementations
impl Freeze for Callout
impl RefUnwindSafe for Callout
impl Send for Callout
impl Sync for Callout
impl Unpin for Callout
impl UnsafeUnpin for Callout
impl UnwindSafe for Callout