pub struct ChartSeries {
pub name: String,
pub data: Vec<f64>,
pub color: Option<String>,
}Expand description
A data series for stacked bar charts.
Fields
name: Stringdata: Vec<f64>color: Option<String>Trait Implementations
Sourceimpl Clone for ChartSeries
impl Clone for ChartSeries
Sourcefn clone(&self) -> ChartSeries
fn clone(&self) -> ChartSeries
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ChartSeries
impl Debug for ChartSeries
Sourceimpl<'de> Deserialize<'de> for ChartSeries
impl<'de> Deserialize<'de> for ChartSeries
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ChartSeries
impl JsonSchema for ChartSeries
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ChartSeries
impl RefUnwindSafe for ChartSeries
impl Send for ChartSeries
impl Sync for ChartSeries
impl Unpin for ChartSeries
impl UnsafeUnpin for ChartSeries
impl UnwindSafe for ChartSeries