pub struct ScatterPoint {
pub x: f64,
pub y: f64,
pub size: f32,
pub color: Option<String>,
}Expand description
A data point for scatter charts with explicit x/y coordinates.
Fields
x: f64y: f64size: f32color: Option<String>Trait Implementations
Sourceimpl Clone for ScatterPoint
impl Clone for ScatterPoint
Sourcefn clone(&self) -> ScatterPoint
fn clone(&self) -> ScatterPoint
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ScatterPoint
impl Debug for ScatterPoint
Sourceimpl<'de> Deserialize<'de> for ScatterPoint
impl<'de> Deserialize<'de> for ScatterPoint
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ScatterPoint
impl JsonSchema for ScatterPoint
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ScatterPoint
impl RefUnwindSafe for ScatterPoint
impl Send for ScatterPoint
impl Sync for ScatterPoint
impl Unpin for ScatterPoint
impl UnsafeUnpin for ScatterPoint
impl UnwindSafe for ScatterPoint