pub struct Comparison {Show 16 fields
pub left_color: String,
pub right_color: String,
pub left_label: Option<String>,
pub right_label: Option<String>,
pub divider_position: f64,
pub animate_from: Option<f64>,
pub animate_to: Option<f64>,
pub animate_at: Option<f64>,
pub animation_duration: f64,
pub divider_color: String,
pub divider_width: f32,
pub border_radius: f32,
pub timing: TimingConfig,
pub style: CssStyle,
pub timeline: Vec<TimelineStep>,
pub stagger: Option<f32>,
}Fields
left_color: Stringright_color: Stringleft_label: Option<String>right_label: Option<String>divider_position: f64animate_from: Option<f64>animate_to: Option<f64>animate_at: Option<f64>animation_duration: f64divider_color: Stringdivider_width: f32border_radius: f32timing: TimingConfigstyle: CssStyletimeline: Vec<TimelineStep>stagger: Option<f32>Trait Implementations
Sourceimpl Animatable for Comparison
impl Animatable for Comparison
fn animation_effects(&self) -> &[AnimationEffect]
Sourcefn timeline_steps(&self) -> &[TimelineStep]
fn timeline_steps(&self) -> &[TimelineStep]
Timed animation steps (
timeline field): each step’s animations are
resolved with delay += step.at. Empty by default.Sourceimpl Debug for Comparison
impl Debug for Comparison
Sourceimpl<'de> Deserialize<'de> for Comparison
impl<'de> Deserialize<'de> for Comparison
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Comparison
impl JsonSchema for Comparison
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Painter for Comparison
impl Painter for Comparison
Sourcefn paint_content(
&self,
canvas: &Canvas,
layout: &BoxLayout,
_props: &AnimatedProperties,
ctx: &PaintCtx,
)
fn paint_content( &self, canvas: &Canvas, layout: &BoxLayout, _props: &AnimatedProperties, ctx: &PaintCtx, )
Paint the component’s content into the canvas. The canvas is
already translated to the content-box origin and clipped if
overflow: hidden was set. Generic decorations (bg, border,
shadow) are already painted by the engine. Read moreSourcefn intrinsic_size(
&self,
_available: AvailableSize,
_ctx: &MeasureCtx,
) -> Option<(f32, f32)>
fn intrinsic_size( &self, _available: AvailableSize, _ctx: &MeasureCtx, ) -> Option<(f32, f32)>
Optional intrinsic measurement for leaves like
text, image,
codeblock. Return None to let taffy compute the size from the
CSS style alone. available mirrors taffy’s AvailableSpace.Sourceimpl Serialize for Comparison
impl Serialize for Comparison
Sourceimpl Styled for Comparison
impl Styled for Comparison
fn style_config(&self) -> &CssStyle
Sourceimpl StyledMut for Comparison
impl StyledMut for Comparison
fn style_config_mut(&mut self) -> &mut CssStyle