pub struct DotMap {
pub points: Vec<MapPoint>,
pub background_color: String,
pub world_dot_color: String,
pub dot_spacing: f32,
pub dot_radius: f32,
pub show_world: bool,
pub animated: bool,
pub animation_duration: f64,
pub timing: TimingConfig,
pub style: CssStyle,
pub timeline: Vec<TimelineStep>,
pub stagger: Option<f32>,
}Fields
points: Vec<MapPoint>background_color: Stringworld_dot_color: StringColor of the world map dots
dot_spacing: f32Spacing between world map dots in pixels
dot_radius: f32Radius of each world map dot
show_world: boolShow world map dot pattern
animated: boolanimation_duration: f64timing: TimingConfigstyle: CssStyletimeline: Vec<TimelineStep>stagger: Option<f32>Trait Implementations
Sourceimpl Animatable for DotMap
impl Animatable for DotMap
fn animation_effects(&self) -> &[AnimationEffect]
Sourcefn timeline_steps(&self) -> &[TimelineStep]
fn timeline_steps(&self) -> &[TimelineStep]
Timed animation steps (
timeline field): each step’s animations are
resolved with delay += step.at. Empty by default.Sourceimpl<'de> Deserialize<'de> for DotMap
impl<'de> Deserialize<'de> for DotMap
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for DotMap
impl JsonSchema for DotMap
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Painter for DotMap
impl Painter for DotMap
Sourcefn paint_content(
&self,
canvas: &Canvas,
layout: &BoxLayout,
_props: &AnimatedProperties,
ctx: &PaintCtx,
)
fn paint_content( &self, canvas: &Canvas, layout: &BoxLayout, _props: &AnimatedProperties, ctx: &PaintCtx, )
Paint the component’s content into the canvas. The canvas is
already translated to the content-box origin and clipped if
overflow: hidden was set. Generic decorations (bg, border,
shadow) are already painted by the engine. Read moreSourcefn intrinsic_size(
&self,
_available: AvailableSize,
_ctx: &MeasureCtx,
) -> Option<(f32, f32)>
fn intrinsic_size( &self, _available: AvailableSize, _ctx: &MeasureCtx, ) -> Option<(f32, f32)>
Optional intrinsic measurement for leaves like
text, image,
codeblock. Return None to let taffy compute the size from the
CSS style alone. available mirrors taffy’s AvailableSpace.Auto Trait Implementations
impl Freeze for DotMap
impl RefUnwindSafe for DotMap
impl Send for DotMap
impl Sync for DotMap
impl Unpin for DotMap
impl UnsafeUnpin for DotMap
impl UnwindSafe for DotMap