pub struct Flex {
pub children: Vec<ChildComponent>,
pub timing: TimingConfig,
pub style: CssStyle,
pub timeline: Vec<TimelineStep>,
pub stagger: Option<f32>,
pub time_scale: Option<f64>,
pub time_offset: Option<f64>,
}Expand description
Flex container — children are positioned via flexbox layout.
Fields
children: Vec<ChildComponent>timing: TimingConfigstyle: CssStyletimeline: Vec<TimelineStep>stagger: Option<f32>time_scale: Option<f64>time_offset: Option<f64>Trait Implementations
Sourceimpl Animatable for Flex
impl Animatable for Flex
fn animation_effects(&self) -> &[AnimationEffect]
Sourcefn timeline_steps(&self) -> &[TimelineStep]
fn timeline_steps(&self) -> &[TimelineStep]
Timed animation steps (
timeline field): each step’s animations are
resolved with delay += step.at. Empty by default.Sourceimpl<'de> Deserialize<'de> for Flex
impl<'de> Deserialize<'de> for Flex
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Flex
impl JsonSchema for Flex
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Painter for Flex
impl Painter for Flex
Sourcefn paint_content(
&self,
_canvas: &Canvas,
_layout: &BoxLayout,
_props: &AnimatedProperties,
_ctx: &PaintCtx,
)
fn paint_content( &self, _canvas: &Canvas, _layout: &BoxLayout, _props: &AnimatedProperties, _ctx: &PaintCtx, )
Paint the component’s content into the canvas. The canvas is
already translated to the content-box origin and clipped if
overflow: hidden was set. Generic decorations (bg, border,
shadow) are already painted by the engine. Read moreSourcefn intrinsic_size(
&self,
_available: AvailableSize,
_ctx: &MeasureCtx,
) -> Option<(f32, f32)>
fn intrinsic_size( &self, _available: AvailableSize, _ctx: &MeasureCtx, ) -> Option<(f32, f32)>
Optional intrinsic measurement for leaves like
text, image,
codeblock. Return None to let taffy compute the size from the
CSS style alone. available mirrors taffy’s AvailableSpace.Auto Trait Implementations
impl Freeze for Flex
impl RefUnwindSafe for Flex
impl Send for Flex
impl Sync for Flex
impl Unpin for Flex
impl UnsafeUnpin for Flex
impl UnwindSafe for Flex