pub struct PillTransition {
pub to: u32,
pub at: f64,
}Fields
to: u32at: f64Trait Implementations
Sourceimpl Clone for PillTransition
impl Clone for PillTransition
Sourcefn clone(&self) -> PillTransition
fn clone(&self) -> PillTransition
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PillTransition
impl Debug for PillTransition
Sourceimpl<'de> Deserialize<'de> for PillTransition
impl<'de> Deserialize<'de> for PillTransition
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for PillTransition
impl JsonSchema for PillTransition
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for PillTransition
impl RefUnwindSafe for PillTransition
impl Send for PillTransition
impl Sync for PillTransition
impl Unpin for PillTransition
impl UnsafeUnpin for PillTransition
impl UnwindSafe for PillTransition