pub struct RichTextSpan {
pub text: String,
pub color: Option<String>,
pub font_size: Option<f32>,
pub font_weight: Option<FontWeight>,
pub font_family: Option<String>,
pub font_style: Option<FontStyleType>,
pub letter_spacing: Option<f32>,
}Expand description
A single styled span within a rich_text component.
Fields
text: Stringcolor: Option<String>font_size: Option<f32>font_weight: Option<FontWeight>font_family: Option<String>font_style: Option<FontStyleType>letter_spacing: Option<f32>Trait Implementations
Sourceimpl Clone for RichTextSpan
impl Clone for RichTextSpan
Sourcefn clone(&self) -> RichTextSpan
fn clone(&self) -> RichTextSpan
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RichTextSpan
impl Debug for RichTextSpan
Sourceimpl<'de> Deserialize<'de> for RichTextSpan
impl<'de> Deserialize<'de> for RichTextSpan
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for RichTextSpan
impl JsonSchema for RichTextSpan
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for RichTextSpan
impl RefUnwindSafe for RichTextSpan
impl Send for RichTextSpan
impl Sync for RichTextSpan
impl Unpin for RichTextSpan
impl UnsafeUnpin for RichTextSpan
impl UnwindSafe for RichTextSpan