pub struct StepItem {
pub label: String,
pub description: Option<String>,
}Fields
label: Stringdescription: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for StepItem
impl<'de> Deserialize<'de> for StepItem
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StepItem
impl JsonSchema for StepItem
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StepItem
impl RefUnwindSafe for StepItem
impl Send for StepItem
impl Sync for StepItem
impl Unpin for StepItem
impl UnsafeUnpin for StepItem
impl UnwindSafe for StepItem