pub struct TerminalLine {
pub text: String,
pub line_type: TerminalLineType,
pub color: Option<String>,
}Fields
text: Stringline_type: TerminalLineTypecolor: Option<String>Trait Implementations
Sourceimpl Clone for TerminalLine
impl Clone for TerminalLine
Sourcefn clone(&self) -> TerminalLine
fn clone(&self) -> TerminalLine
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TerminalLine
impl Debug for TerminalLine
Sourceimpl<'de> Deserialize<'de> for TerminalLine
impl<'de> Deserialize<'de> for TerminalLine
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TerminalLine
impl JsonSchema for TerminalLine
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TerminalLine
impl RefUnwindSafe for TerminalLine
impl Send for TerminalLine
impl Sync for TerminalLine
impl Unpin for TerminalLine
impl UnsafeUnpin for TerminalLine
impl UnwindSafe for TerminalLine