pub struct Timeline {Show 15 fields
pub steps: Vec<TimelineStep>,
pub width: f32,
pub direction: TimelineDirection,
pub node_radius: f32,
pub bar_color: String,
pub bar_fill_color: String,
pub bar_height: f32,
pub fill_progress: f32,
pub font_size: f32,
pub label_color: String,
pub sublabel_color: String,
pub timing: TimingConfig,
pub style: CssStyle,
pub timeline: Vec<TimelineStep>,
pub stagger: Option<f32>,
}Expand description
A horizontal or vertical pipeline/timeline component.
Fields
steps: Vec<TimelineStep>The steps in the pipeline.
width: f32Overall width of the timeline.
direction: TimelineDirectionDirection: “horizontal” (default) or “vertical”.
node_radius: f32Radius of the step circles.
bar_color: StringColor of the connecting bar background.
bar_fill_color: StringColor of the filled portion of the bar.
bar_height: f32Bar thickness.
fill_progress: f32Fill progress (0.0 to 1.0) — animates the bar from left to right.
font_size: f32Font size for labels.
label_color: StringLabel color.
sublabel_color: StringSublabel color.
timing: TimingConfigstyle: CssStyletimeline: Vec<TimelineStep>stagger: Option<f32>Trait Implementations
Sourceimpl Animatable for Timeline
impl Animatable for Timeline
fn animation_effects(&self) -> &[AnimationEffect]
Sourcefn timeline_steps(&self) -> &[TimelineStep]
fn timeline_steps(&self) -> &[TimelineStep]
Timed animation steps (
timeline field): each step’s animations are
resolved with delay += step.at. Empty by default.Sourceimpl<'de> Deserialize<'de> for Timeline
impl<'de> Deserialize<'de> for Timeline
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Timeline
impl JsonSchema for Timeline
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Painter for Timeline
impl Painter for Timeline
Sourcefn paint_content(
&self,
canvas: &Canvas,
_layout: &BoxLayout,
props: &AnimatedProperties,
_ctx: &PaintCtx,
)
fn paint_content( &self, canvas: &Canvas, _layout: &BoxLayout, props: &AnimatedProperties, _ctx: &PaintCtx, )
Paint the component’s content into the canvas. The canvas is
already translated to the content-box origin and clipped if
overflow: hidden was set. Generic decorations (bg, border,
shadow) are already painted by the engine. Read moreSourcefn intrinsic_size(
&self,
_available: AvailableSize,
_ctx: &MeasureCtx,
) -> Option<(f32, f32)>
fn intrinsic_size( &self, _available: AvailableSize, _ctx: &MeasureCtx, ) -> Option<(f32, f32)>
Optional intrinsic measurement for leaves like
text, image,
codeblock. Return None to let taffy compute the size from the
CSS style alone. available mirrors taffy’s AvailableSpace.Auto Trait Implementations
impl Freeze for Timeline
impl RefUnwindSafe for Timeline
impl Send for Timeline
impl Sync for Timeline
impl Unpin for Timeline
impl UnsafeUnpin for Timeline
impl UnwindSafe for Timeline