pub struct Tooltip {
pub text: String,
pub arrow: TooltipArrow,
pub font_size: f32,
pub background_color: String,
pub text_color: String,
pub arrow_size: f32,
pub border_color: Option<String>,
pub timing: TimingConfig,
pub style: CssStyle,
pub timeline: Vec<TimelineStep>,
pub stagger: Option<f32>,
}Fields
text: Stringarrow: TooltipArrowfont_size: f32background_color: Stringtext_color: Stringarrow_size: f32border_color: Option<String>timing: TimingConfigstyle: CssStyletimeline: Vec<TimelineStep>stagger: Option<f32>Trait Implementations
Sourceimpl Animatable for Tooltip
impl Animatable for Tooltip
fn animation_effects(&self) -> &[AnimationEffect]
Sourcefn timeline_steps(&self) -> &[TimelineStep]
fn timeline_steps(&self) -> &[TimelineStep]
Timed animation steps (
timeline field): each step’s animations are
resolved with delay += step.at. Empty by default.Sourceimpl<'de> Deserialize<'de> for Tooltip
impl<'de> Deserialize<'de> for Tooltip
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for Tooltip
impl JsonSchema for Tooltip
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl Painter for Tooltip
impl Painter for Tooltip
Sourcefn paint_content(
&self,
canvas: &Canvas,
layout: &BoxLayout,
_props: &AnimatedProperties,
ctx: &PaintCtx,
)
fn paint_content( &self, canvas: &Canvas, layout: &BoxLayout, _props: &AnimatedProperties, ctx: &PaintCtx, )
Paint the component’s content into the canvas. The canvas is
already translated to the content-box origin and clipped if
overflow: hidden was set. Generic decorations (bg, border,
shadow) are already painted by the engine. Read moreSourcefn intrinsic_size(
&self,
_available: AvailableSize,
_ctx: &MeasureCtx,
) -> Option<(f32, f32)>
fn intrinsic_size( &self, _available: AvailableSize, _ctx: &MeasureCtx, ) -> Option<(f32, f32)>
Optional intrinsic measurement for leaves like
text, image,
codeblock. Return None to let taffy compute the size from the
CSS style alone. available mirrors taffy’s AvailableSpace.Auto Trait Implementations
impl Freeze for Tooltip
impl RefUnwindSafe for Tooltip
impl Send for Tooltip
impl Sync for Tooltip
impl Unpin for Tooltip
impl UnsafeUnpin for Tooltip
impl UnwindSafe for Tooltip